@@ -3,6 +3,7 @@ use alloc::string::ToString;
 use core::{
     fmt::{Debug, Formatter, Result as FmtResult},
     hash::Hash,
+    iter::FromIterator,
     ops::Index,
     str::FromStr,
 };
@@ -25,10 +26,7 @@ macro_rules! as_method {
 macro_rules! as_num_method {
     {$(#[$meta:meta])* fn $id:ident = $ty1:ident $(| $ty2:ident)*} => {
         $(#[$meta])*
-        pub fn $id<N>(&self) -> Result<N, u64>
-        where
-            N: FromStr,
-        {
+        pub fn $id<N: FromStr>(&self) -> Result<N, u64> {
             match self.yaml() {
                 YamlBase::$ty1(n) $(| YamlBase::$ty2(n))* => match n.parse() {
                     Ok(v) => Ok(v),
@@ -40,6 +38,20 @@ macro_rules! as_num_method {
     };
 }
 
+macro_rules! impl_iter {
+    ($item:ty) => {
+        impl<R: Repr> FromIterator<$item> for NodeBase<R> {
+            fn from_iter<T: IntoIterator<Item = $item>>(iter: T) -> Self {
+                Self::from(iter.into_iter().collect::<YamlBase<R>>())
+            }
+        }
+    };
+    ($item1:ty $(, $item2:ty)*) => {
+        impl_iter!{$item1}
+        $(impl_iter!{$item2})*
+    }
+}
+
 /// A node with [`alloc::rc::Rc`] holder.
 pub type Node = NodeBase<RcRepr>;
 /// A node with [`alloc::sync::Arc`] holder.
@@ -322,10 +334,7 @@ impl<R: Repr> NodeBase<R> {
     /// assert_eq!(node!(30.), n.get("a")?.get("b")?);
     /// # Ok::<(), u64>(()) }
     /// ```
-    pub fn get<Y>(&self, keys: Y) -> Result<Self, u64>
-    where
-        Y: Into<Self> + Copy,
-    {
+    pub fn get<Y: Into<Self>>(&self, keys: Y) -> Result<Self, u64> {
         if let YamlBase::Map(m) = self.yaml() {
             if let Some(n) = m.get(&keys.into()) {
                 Ok(n.clone())
@@ -382,7 +391,7 @@ impl<R: Repr> NodeBase<R> {
         factory: F,
     ) -> Result<Ret, u64>
     where
-        Y: Into<Self> + Copy,
+        Y: Into<Self>,
         F: Fn(&'a Self) -> Result<Ret, u64>,
     {
         if let YamlBase::Map(m) = self.yaml() {
@@ -466,3 +475,5 @@ where
         Self::new(yaml.into(), 0, "", "")
     }
 }
+
+impl_iter! {Self, (Self, Self)}
